==> libreoffice-fresh-sdk-7.2.2-4-x86_64.pkg.tar.zst: usr/share/doc/libreoffice/sdk/docs/idl/ref/search/enumvalues_3.js <==
var searchData=
[
  ['dash_0',['DASH',['../namespacecom_1_1sun_1_1star_1_1drawing.html#a86e0f5648542856159bb40775c854aa7a36f7cc172dfe8846b32b3bb288d1221f',1,'com::sun::star::drawing']]],
  ['data_1',['DATA',['../namespacecom_1_1sun_1_1star_1_1sheet.html#a686c797e7cb837947558aa11c946245aa9d7d6f31868d66330397c967c4afd2d2',1,'com::sun::star::sheet']]],
  ['data_5fnot_5fmatch_2',['DATA_NOT_MATCH',['../namespacecom_1_1sun_1_1star_1_1xml_1_1crypto.html#ab5d887eb5da1173b766d96d0d863d1dca268ca8de336825f0052f0d0c0a5f116f',1,'com::sun::star::xml::crypto']]],
  ['data_5frange_3',['DATA_RANGE',['../namespacecom_1_1sun_1_1star_1_1chart.html#a37b4d47e7d1600aa406ad115a39fe1daa4860f33e6356683507e65dfc612a7f51',1,'com::sun::star::chart']]],
  ['date_4',['DATE',['../namespacecom_1_1sun_1_1star_1_1sheet.html#aa5aa6dbecaeb5e18a476b0a58279c57aac7cae48a020e5f4fb68bd638aa5fb7d9',1,'com::sun::star::sheet']]],
  ['decimal_5',['DECIMAL',['../namespacecom_1_1sun_1_1star_1_1sheet.html#aa5aa6dbecaeb5e18a476b0a58279c57aaf08a543d5a1549321682e12569d0fbd6',1,'com::sun::star::sheet::DECIMAL()'],['../namespacecom_1_1sun_1_1star_1_1style.html#a806c06853615662029f86b19111fe0a2af08a543d5a1549321682e12569d0fbd6',1,'com::sun::star::style::DECIMAL()']]],
  ['deep_6',['DEEP',['../namespacecom_1_1sun_1_1star_1_1ucb.html#a8f357eda7c29e9601428bdc8834c7bd8aacb8a89517457d70c8cfc3c47c31ecc1',1,'com::sun::star::ucb']]],
  ['default_7',['Default',['../namespacecom_1_1sun_1_1star_1_1mozilla.html#a2bcdf854763e98ee224085041ac2ffa5a79935518a3889663d8688b6b01fff051',1,'com::sun::star::mozilla']]],
  ['default_8',['DEFAULT',['../namespacecom_1_1sun_1_1star_1_1sheet.html#a1b95ca535d92ad726d77981ea3d8ef8ba88ec7d5086d2469ba843c7fcceade8a6',1,'com::sun::star::sheet::DEFAULT()'],['../namespacecom_1_1sun_1_1star_1_1style.html#a806c06853615662029f86b19111fe0a2a88ec7d5086d2469ba843c7fcceade8a6',1,'com::sun::star::style::DEFAULT()']]],
  ['default_5fvalue_9',['DEFAULT_VALUE',['../namespacecom_1_1sun_1_1star_1_1beans.html#a1a5ccb5c59cace4a214c1e2eae8620b0a1ab389dd2f45c27c40878403ff15a2bf',1,'com::sun::star::beans']]],
  ['delete_10',['DELETE',['../namespacecom_1_1sun_1_1star_1_1ucb.html#a3c143367536e0c519b25183505ae3ed7a9d61e82a9a12752f10aece1b22183913',1,'com::sun::star::ucb']]],
  ['device_5fnot_5fready_11',['DEVICE_NOT_READY',['../namespacecom_1_1sun_1_1star_1_1ucb.html#ab0378c2985abaca86838ed9936c3a2d5a24c53d2c7061acc97015d6c6b588af27',1,'com::sun::star::ucb']]],
  ['different_5fdevices_12',['DIFFERENT_DEVICES',['../namespacecom_1_1sun_1_1star_1_1ucb.html#ab0378c2985abaca86838ed9936c3a2d5acf00f2ac62742673be1fbc142e696751',1,'com::sun::star::ucb']]],
  ['dimensioniang_5flines_13',['DIMENSIONIANG_LINES',['../namespacecom_1_1sun_1_1star_1_1drawing.html#a56943a0946e5f15e5e58054b8e7a04a4acd7a284aab578e3b30cc411abb0eaa97',1,'com::sun::star::drawing']]],
  ['dir_5fnon_5fspacing_5fmark_14',['DIR_NON_SPACING_MARK',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a6e8fd3df14c13e43a44061c70daacd8baae64527b4b69b8d54e909c6f3abb7df5',1,'com::sun::star::i18n']]],
  ['direct_15',['DIRECT',['../namespacecom_1_1sun_1_1star_1_1drawing_1_1framework.html#af2624f1e14ec2ab7890946d97b26724ca1ea328a644e627283a35716a54108248',1,'com::sun::star::drawing::framework']]],
  ['direct_5fvalue_16',['DIRECT_VALUE',['../namespacecom_1_1sun_1_1star_1_1beans.html#a1a5ccb5c59cace4a214c1e2eae8620b0ad7c3cb15d1af996cf88af93f72447c73',1,'com::sun::star::beans']]],
  ['directory_5fname_17',['DIRECTORY_NAME',['../namespacecom_1_1sun_1_1star_1_1security.html#a5c5a31742567126d2ba88393b05efa3fa049dfc8d79668523c2ba2eb674f2c50c',1,'com::sun::star::security']]],
  ['disabled_18',['DISABLED',['../namespacecom_1_1sun_1_1star_1_1xml_1_1crypto.html#ab5d887eb5da1173b766d96d0d863d1dca40f39385238042f6ec0cbac821a19fc4',1,'com::sun::star::xml::crypto']]],
  ['dissolve_19',['DISSOLVE',['../namespacecom_1_1sun_1_1star_1_1presentation.html#a9db0b8c5e72e0ae290ff76da0dd53e3daeb6ce808d98ae1927e478be15983d6c3',1,'com::sun::star::presentation']]],
  ['divide_20',['DIVIDE',['../namespacecom_1_1sun_1_1star_1_1sheet.html#af53d63b24461405946937e0b962a8a9ba0cb86713ee09fe297dde9ab03d50d5da',1,'com::sun::star::sheet']]],
  ['dns_5fname_21',['DNS_NAME',['../namespacecom_1_1sun_1_1star_1_1security.html#a5c5a31742567126d2ba88393b05efa3faf96e2602fa1bf65ccce4935dc203f392',1,'com::sun::star::security']]],
  ['doc_5fend_22',['DOC_END',['../namespacecom_1_1sun_1_1star_1_1text.html#a95d9f731f1389ee9f277e756b476251ca3828017543ed76335f58a4e21298ddbe',1,'com::sun::star::text']]],
  ['dockingarea_5fbottom_23',['DOCKINGAREA_BOTTOM',['../namespacecom_1_1sun_1_1star_1_1ui.html#abab7084b80a737f798ccebf692878cc1a5165d560a85dc0cdb0c8d6a8baeaab48',1,'com::sun::star::ui']]],
  ['dockingarea_5fdefault_24',['DOCKINGAREA_DEFAULT',['../namespacecom_1_1sun_1_1star_1_1ui.html#abab7084b80a737f798ccebf692878cc1a0df3afb5d877bcd00abaae204f970dfa',1,'com::sun::star::ui']]],
  ['dockingarea_5fleft_25',['DOCKINGAREA_LEFT',['../namespacecom_1_1sun_1_1star_1_1ui.html#abab7084b80a737f798ccebf692878cc1a27b4f90edc6f247ec06eb866fd54c3e2',1,'com::sun::star::ui']]],
  ['dockingarea_5fright_26',['DOCKINGAREA_RIGHT',['../namespacecom_1_1sun_1_1star_1_1ui.html#abab7084b80a737f798ccebf692878cc1a9ca6636e41c120e8ceeeaffe4efaf39a',1,'com::sun::star::ui']]],
  ['dockingarea_5ftop_27',['DOCKINGAREA_TOP',['../namespacecom_1_1sun_1_1star_1_1ui.html#abab7084b80a737f798ccebf692878cc1a3d08527205e612af810aea0496e55796',1,'com::sun::star::ui']]],
  ['document_28',['DOCUMENT',['../namespacecom_1_1sun_1_1star_1_1presentation.html#a85fe75121d351785616b75b2c5661d8fa17d721d5d0d3fece4d72a45689a899fb',1,'com::sun::star::presentation']]],
  ['document_5ffinished_29',['DOCUMENT_FINISHED',['../namespacecom_1_1sun_1_1star_1_1xml_1_1dom.html#a8e1d723b2d19d95078879bf81b535b36a4a48554467110b56b5e4a253329ea018',1,'com::sun::star::xml::dom']]],
  ['document_5ffragment_5fnode_30',['DOCUMENT_FRAGMENT_NODE',['../namespacecom_1_1sun_1_1star_1_1xml_1_1dom.html#acac9cbaeea226ed297804c012dc12b16aac88849f3dfadda226c0533e0dc5cfb4',1,'com::sun::star::xml::dom']]],
  ['document_5fnode_31',['DOCUMENT_NODE',['../namespacecom_1_1sun_1_1star_1_1xml_1_1dom.html#acac9cbaeea226ed297804c012dc12b16aa170f5bd4256511bbbcb5d7946e5637d',1,'com::sun::star::xml::dom']]],
  ['document_5ftype_5fnode_32',['DOCUMENT_TYPE_NODE',['../namespacecom_1_1sun_1_1star_1_1xml_1_1dom.html#acac9cbaeea226ed297804c012dc12b16a3a922342f537c7003ffe5ffd01b15476',1,'com::sun::star::xml::dom']]],
  ['domactivate_33',['DOMActivate',['../namespacecom_1_1sun_1_1star_1_1xml_1_1dom_1_1events.html#a2628ea8d12e8b2563c32f05dc7fff6faaf90388ceafff4112f76d5d682a6796ea',1,'com::sun::star::xml::dom::events']]],
  ['domattrmodified_34',['DOMAttrModified',['../namespacecom_1_1sun_1_1star_1_1xml_1_1dom_1_1events.html#a2628ea8d12e8b2563c32f05dc7fff6faa14447f85deb85c44eae9fd1e1194ed3d',1,'com::sun::star::xml::dom::events']]],
  ['domcharacterdatamodified_35',['DOMCharacterDataModified',['../namespacecom_1_1sun_1_1star_1_1xml_1_1dom_1_1events.html#a2628ea8d12e8b2563c32f05dc7fff6faa5947a8ba43363ca1a7ee5eb7c08c7fb5',1,'com::sun::star::xml::dom::events']]],
  ['domfocusin_36',['DOMFocusIn',['../namespacecom_1_1sun_1_1star_1_1xml_1_1dom_1_1events.html#a2628ea8d12e8b2563c32f05dc7fff6faaaf1359e0904466b1dfdcc43613f014c0',1,'com::sun::star::xml::dom::events']]],
  ['domfocusout_37',['DOMFocusOut',['../namespacecom_1_1sun_1_1star_1_1xml_1_1dom_1_1events.html#a2628ea8d12e8b2563c32f05dc7fff6faa9be4590c2b74592c0080dd6a2f035332',1,'com::sun::star::xml::dom::events']]],
  ['domnodeinserted_38',['DOMNodeInserted',['../namespacecom_1_1sun_1_1star_1_1xml_1_1dom_1_1events.html#a2628ea8d12e8b2563c32f05dc7fff6faa154c0ab82bf1f76b3e78dc21cade1972',1,'com::sun::star::xml::dom::events']]],
  ['domnodeinsertedintodocument_39',['DOMNodeInsertedIntoDocument',['../namespacecom_1_1sun_1_1star_1_1xml_1_1dom_1_1events.html#a2628ea8d12e8b2563c32f05dc7fff6faaa440247113307f6cb06f87f0cd1bde07',1,'com::sun::star::xml::dom::events']]],
  ['domnoderemoved_40',['DOMNodeRemoved',['../namespacecom_1_1sun_1_1star_1_1xml_1_1dom_1_1events.html#a2628ea8d12e8b2563c32f05dc7fff6faa66881e427f29b5a0c0ca0e036761e0f6',1,'com::sun::star::xml::dom::events']]],
  ['domnoderemovedfromdocument_41',['DOMNodeRemovedFromDocument',['../namespacecom_1_1sun_1_1star_1_1xml_1_1dom_1_1events.html#a2628ea8d12e8b2563c32f05dc7fff6faa385e5851ecb590684e4cf8531ac1e077',1,'com::sun::star::xml::dom::events']]],
  ['domstring_5fsize_5ferr_42',['DOMSTRING_SIZE_ERR',['../namespacecom_1_1sun_1_1star_1_1xml_1_1dom.html#a31e3fb46d584de1cfc4b4c7640a41239aeb3df344e911d051771206196bdf2b21',1,'com::sun::star::xml::dom']]],
  ['domsubtreemodified_43',['DOMSubtreeModified',['../namespacecom_1_1sun_1_1star_1_1xml_1_1dom_1_1events.html#a2628ea8d12e8b2563c32f05dc7fff6faa919fe92dbd9cd02f40a1e58f057d77bc',1,'com::sun::star::xml::dom::events']]],
  ['done_44',['DONE',['../namespacecom_1_1sun_1_1star_1_1util.html#a78015743cb8b25dbfc2b64889f6bd261a9c954bcf443428c80b0f107b3bc48749',1,'com::sun::star::util']]],
  ['dontknow_45',['DONTKNOW',['../namespacecom_1_1sun_1_1star_1_1awt.html#a0014b68cdf9686458deff56691368317adda60c0d628684cddc307a0bda81a260',1,'com::sun::star::awt']]],
  ['double_46',['DOUBLE',['../namespacecom_1_1sun_1_1star_1_1drawing.html#a021284aa8478781ba1b958b81da7b608a33465d1d419b1074fb259ef444609e92',1,'com::sun::star::drawing::DOUBLE()'],['../namespacecom_1_1sun_1_1star_1_1uno.html#a00683ed3ec24b47c36ead10a20d6f328a33465d1d419b1074fb259ef444609e92',1,'com::sun::star::uno::DOUBLE()']]],
  ['down_47',['DOWN',['../namespacecom_1_1sun_1_1star_1_1drawing.html#a218f9e180f159784cd3e33cef99bfe86a4ebb08896e48bdf5c496da779cbd955c',1,'com::sun::star::drawing::DOWN()'],['../namespacecom_1_1sun_1_1star_1_1sheet.html#a93cdb08109d5d34543f2fe04d1ef605aa9b0b4a95b99523966e0e34ffdadac9da',1,'com::sun::star::sheet::DOWN()']]],
  ['draft_48',['DRAFT',['../namespacecom_1_1sun_1_1star_1_1drawing.html#af49ab4b65513d2c0077f76b2227326e9a0b18dcbaa244a964cf244b6e3e894a28',1,'com::sun::star::drawing']]],
  ['draw_49',['DRAW',['../namespacecom_1_1sun_1_1star_1_1drawing.html#a15072729125e991609f3df469a03f611a61f3c57b6943c85413975507aede78cd',1,'com::sun::star::drawing']]],
  ['dsig_5finvalid_5freference_50',['DSIG_INVALID_REFERENCE',['../namespacecom_1_1sun_1_1star_1_1xml_1_1crypto.html#ab5d887eb5da1173b766d96d0d863d1dca770034bf39a46320ab5fc8df92ac3dee',1,'com::sun::star::xml::crypto']]],
  ['dsig_5fno_5freferences_51',['DSIG_NO_REFERENCES',['../namespacecom_1_1sun_1_1star_1_1xml_1_1crypto.html#ab5d887eb5da1173b766d96d0d863d1dca40b08485b5060322a1665ee640f6e7ab',1,'com::sun::star::xml::crypto']]],
  ['dynamic_52',['DYNAMIC',['../namespacecom_1_1sun_1_1star_1_1text.html#a1ed96de3f2d76e93588f67d506a0b0aeaaac65e0072e6ff1f4c3209d2fdd8730a',1,'com::sun::star::text']]]
];

==> libreoffice-fresh-sdk-7.4.1-3-x86_64.pkg.tar.zst: usr/share/doc/libreoffice/sdk/docs/idl/ref/search/enumvalues_3.js <==
var searchData=
[
  ['dash_0',['DASH',['../namespacecom_1_1sun_1_1star_1_1drawing.html#a86e0f5648542856159bb40775c854aa7a36f7cc172dfe8846b32b3bb288d1221f',1,'com::sun::star::drawing']]],
  ['data_1',['DATA',['../namespacecom_1_1sun_1_1star_1_1sheet.html#a686c797e7cb837947558aa11c946245aa9d7d6f31868d66330397c967c4afd2d2',1,'com::sun::star::sheet']]],
  ['data_5fnot_5fmatch_2',['DATA_NOT_MATCH',['../namespacecom_1_1sun_1_1star_1_1xml_1_1crypto.html#ab5d887eb5da1173b766d96d0d863d1dca268ca8de336825f0052f0d0c0a5f116f',1,'com::sun::star::xml::crypto']]],
  ['data_5frange_3',['DATA_RANGE',['../namespacecom_1_1sun_1_1star_1_1chart.html#a37b4d47e7d1600aa406ad115a39fe1daa4860f33e6356683507e65dfc612a7f51',1,'com::sun::star::chart']]],
  ['date_4',['DATE',['../namespacecom_1_1sun_1_1star_1_1sheet.html#aa5aa6dbecaeb5e18a476b0a58279c57aac7cae48a020e5f4fb68bd638aa5fb7d9',1,'com::sun::star::sheet']]],
  ['decimal_5',['DECIMAL',['../namespacecom_1_1sun_1_1star_1_1sheet.html#aa5aa6dbecaeb5e18a476b0a58279c57aaf08a543d5a1549321682e12569d0fbd6',1,'com::sun::star::sheet::DECIMAL()'],['../namespacecom_1_1sun_1_1star_1_1style.html#a806c06853615662029f86b19111fe0a2af08a543d5a1549321682e12569d0fbd6',1,'com::sun::star::style::DECIMAL()']]],
  ['deep_6',['DEEP',['../namespacecom_1_1sun_1_1star_1_1ucb.html#a8f357eda7c29e9601428bdc8834c7bd8aacb8a89517457d70c8cfc3c47c31ecc1',1,'com::sun::star::ucb']]],
  ['default_7',['DEFAULT',['../namespacecom_1_1sun_1_1star_1_1sheet.html#a1b95ca535d92ad726d77981ea3d8ef8ba88ec7d5086d2469ba843c7fcceade8a6',1,'com::sun::star::sheet::DEFAULT()'],['../namespacecom_1_1sun_1_1star_1_1style.html#a806c06853615662029f86b19111fe0a2a88ec7d5086d2469ba843c7fcceade8a6',1,'com::sun::star::style::DEFAULT()']]],
  ['default_8',['Default',['../namespacecom_1_1sun_1_1star_1_1mozilla.html#a2bcdf854763e98ee224085041ac2ffa5a79935518a3889663d8688b6b01fff051',1,'com::sun::star::mozilla']]],
  ['default_5fvalue_9',['DEFAULT_VALUE',['../namespacecom_1_1sun_1_1star_1_1beans.html#a1a5ccb5c59cace4a214c1e2eae8620b0a1ab389dd2f45c27c40878403ff15a2bf',1,'com::sun::star::beans']]],
  ['delete_10',['DELETE',['../namespacecom_1_1sun_1_1star_1_1ucb.html#a3c143367536e0c519b25183505ae3ed7a9d61e82a9a12752f10aece1b22183913',1,'com::sun::star::ucb']]],
  ['device_5fnot_5fready_11',['DEVICE_NOT_READY',['../namespacecom_1_1sun_1_1star_1_1ucb.html#ab0378c2985abaca86838ed9936c3a2d5a24c53d2c7061acc97015d6c6b588af27',1,'com::sun::star::ucb']]],
  ['different_5fdevices_12',['DIFFERENT_DEVICES',['../namespacecom_1_1sun_1_1star_1_1ucb.html#ab0378c2985abaca86838ed9936c3a2d5acf00f2ac62742673be1fbc142e696751',1,'com::sun::star::ucb']]],
  ['dimensioniang_5flines_13',['DIMENSIONIANG_LINES',['../namespacecom_1_1sun_1_1star_1_1drawing.html#a56943a0946e5f15e5e58054b8e7a04a4acd7a284aab578e3b30cc411abb0eaa97',1,'com::sun::star::drawing']]],
  ['dir_5fnon_5fspacing_5fmark_14',['DIR_NON_SPACING_MARK',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a6e8fd3df14c13e43a44061c70daacd8baae64527b4b69b8d54e909c6f3abb7df5',1,'com::sun::star::i18n']]],
  ['direct_15',['DIRECT',['../namespacecom_1_1sun_1_1star_1_1drawing_1_1framework.html#af2624f1e14ec2ab7890946d97b26724ca1ea328a644e627283a35716a54108248',1,'com::sun::star::drawing::framework']]],
  ['direct_5fvalue_16',['DIRECT_VALUE',['../namespacecom_1_1sun_1_1star_1_1beans.html#a1a5ccb5c59cace4a214c1e2eae8620b0ad7c3cb15d1af996cf88af93f72447c73',1,'com::sun::star::beans']]],
  ['directory_5fname_17',['DIRECTORY_NAME',['../namespacecom_1_1sun_1_1star_1_1security.html#a5c5a31742567126d2ba88393b05efa3fa049dfc8d79668523c2ba2eb674f2c50c',1,'com::sun::star::security']]],
  ['disabled_18',['DISABLED',['../namespacecom_1_1sun_1_1star_1_1xml_1_1crypto.html#ab5d887eb5da1173b766d96d0d863d1dca40f39385238042f6ec0cbac821a19fc4',1,'com::sun::star::xml::crypto']]],
  ['dissolve_19',['DISSOLVE',['../namespacecom_1_1sun_1_1star_1_1presentation.html#a9db0b8c5e72e0ae290ff76da0dd53e3daeb6ce808d98ae1927e478be15983d6c3',1,'com::sun::star::presentation']]],
  ['divide_20',['DIVIDE',['../namespacecom_1_1sun_1_1star_1_1sheet.html#af53d63b24461405946937e0b962a8a9ba0cb86713ee09fe297dde9ab03d50d5da',1,'com::sun::star::sheet']]],
  ['dns_5fname_21',['DNS_NAME',['../namespacecom_1_1sun_1_1star_1_1security.html#a5c5a31742567126d2ba88393b05efa3faf96e2602fa1bf65ccce4935dc203f392',1,'com::sun::star::security']]],
  ['doc_5fend_22',['DOC_END',['../namespacecom_1_1sun_1_1star_1_1text.html#a95d9f731f1389ee9f277e756b476251ca3828017543ed76335f58a4e21298ddbe',1,'com::sun::star::text']]],
  ['dockingarea_5fbottom_23',['DOCKINGAREA_BOTTOM',['../namespacecom_1_1sun_1_1star_1_1ui.html#abab7084b80a737f798ccebf692878cc1a5165d560a85dc0cdb0c8d6a8baeaab48',1,'com::sun::star::ui']]],
  ['dockingarea_5fdefault_24',['DOCKINGAREA_DEFAULT',['../namespacecom_1_1sun_1_1star_1_1ui.html#abab7084b80a737f798ccebf692878cc1a0df3afb5d877bcd00abaae204f970dfa',1,'com::sun::star::ui']]],
  ['dockingarea_5fleft_25',['DOCKINGAREA_LEFT',['../namespacecom_1_1sun_1_1star_1_1ui.html#abab7084b80a737f798ccebf692878cc1a27b4f90edc6f247ec06eb866fd54c3e2',1,'com::sun::star::ui']]],
  ['dockingarea_5fright_26',['DOCKINGAREA_RIGHT',['../namespacecom_1_1sun_1_1star_1_1ui.html#abab7084b80a737f798ccebf692878cc1a9ca6636e41c120e8ceeeaffe4efaf39a',1,'com::sun::star::ui']]],
  ['dockingarea_5ftop_27',['DOCKINGAREA_TOP',['../namespacecom_1_1sun_1_1star_1_1ui.html#abab7084b80a737f798ccebf692878cc1a3d08527205e612af810aea0496e55796',1,'com::sun::star::ui']]],
  ['document_28',['DOCUMENT',['../namespacecom_1_1sun_1_1star_1_1presentation.html#a85fe75121d351785616b75b2c5661d8fa17d721d5d0d3fece4d72a45689a899fb',1,'com::sun::star::presentation']]],
  ['document_5ffinished_29',['DOCUMENT_FINISHED',['../namespacecom_1_1sun_1_1star_1_1xml_1_1dom.html#a8e1d723b2d19d95078879bf81b535b36a4a48554467110b56b5e4a253329ea018',1,'com::sun::star::xml::dom']]],
  ['document_5ffragment_5fnode_30',['DOCUMENT_FRAGMENT_NODE',['../namespacecom_1_1sun_1_1star_1_1xml_1_1dom.html#acac9cbaeea226ed297804c012dc12b16aac88849f3dfadda226c0533e0dc5cfb4',1,'com::sun::star::xml::dom']]],
  ['document_5fnode_31',['DOCUMENT_NODE',['../namespacecom_1_1sun_1_1star_1_1xml_1_1dom.html#acac9cbaeea226ed297804c012dc12b16aa170f5bd4256511bbbcb5d7946e5637d',1,'com::sun::star::xml::dom']]],
  ['document_5ftype_5fnode_32',['DOCUMENT_TYPE_NODE',['../namespacecom_1_1sun_1_1star_1_1xml_1_1dom.html#acac9cbaeea226ed297804c012dc12b16a3a922342f537c7003ffe5ffd01b15476',1,'com::sun::star::xml::dom']]],
  ['domactivate_33',['DOMActivate',['../namespacecom_1_1sun_1_1star_1_1xml_1_1dom_1_1events.html#a2628ea8d12e8b2563c32f05dc7fff6faaf90388ceafff4112f76d5d682a6796ea',1,'com::sun::star::xml::dom::events']]],
  ['domattrmodified_34',['DOMAttrModified',['../namespacecom_1_1sun_1_1star_1_1xml_1_1dom_1_1events.html#a2628ea8d12e8b2563c32f05dc7fff6faa14447f85deb85c44eae9fd1e1194ed3d',1,'com::sun::star::xml::dom::events']]],
  ['domcharacterdatamodified_35',['DOMCharacterDataModified',['../namespacecom_1_1sun_1_1star_1_1xml_1_1dom_1_1events.html#a2628ea8d12e8b2563c32f05dc7fff6faa5947a8ba43363ca1a7ee5eb7c08c7fb5',1,'com::sun::star::xml::dom::events']]],
  ['domfocusin_36',['DOMFocusIn',['../namespacecom_1_1sun_1_1star_1_1xml_1_1dom_1_1events.html#a2628ea8d12e8b2563c32f05dc7fff6faaaf1359e0904466b1dfdcc43613f014c0',1,'com::sun::star::xml::dom::events']]],
  ['domfocusout_37',['DOMFocusOut',['../namespacecom_1_1sun_1_1star_1_1xml_1_1dom_1_1events.html#a2628ea8d12e8b2563c32f05dc7fff6faa9be4590c2b74592c0080dd6a2f035332',1,'com::sun::star::xml::dom::events']]],
  ['domnodeinserted_38',['DOMNodeInserted',['../namespacecom_1_1sun_1_1star_1_1xml_1_1dom_1_1events.html#a2628ea8d12e8b2563c32f05dc7fff6faa154c0ab82bf1f76b3e78dc21cade1972',1,'com::sun::star::xml::dom::events']]],
  ['domnodeinsertedintodocument_39',['DOMNodeInsertedIntoDocument',['../namespacecom_1_1sun_1_1star_1_1xml_1_1dom_1_1events.html#a2628ea8d12e8b2563c32f05dc7fff6faaa440247113307f6cb06f87f0cd1bde07',1,'com::sun::star::xml::dom::events']]],
  ['domnoderemoved_40',['DOMNodeRemoved',['../namespacecom_1_1sun_1_1star_1_1xml_1_1dom_1_1events.html#a2628ea8d12e8b2563c32f05dc7fff6faa66881e427f29b5a0c0ca0e036761e0f6',1,'com::sun::star::xml::dom::events']]],
  ['domnoderemovedfromdocument_41',['DOMNodeRemovedFromDocument',['../namespacecom_1_1sun_1_1star_1_1xml_1_1dom_1_1events.html#a2628ea8d12e8b2563c32f05dc7fff6faa385e5851ecb590684e4cf8531ac1e077',1,'com::sun::star::xml::dom::events']]],
  ['domstring_5fsize_5ferr_42',['DOMSTRING_SIZE_ERR',['../namespacecom_1_1sun_1_1star_1_1xml_1_1dom.html#a31e3fb46d584de1cfc4b4c7640a41239aeb3df344e911d051771206196bdf2b21',1,'com::sun::star::xml::dom']]],
  ['domsubtreemodified_43',['DOMSubtreeModified',['../namespacecom_1_1sun_1_1star_1_1xml_1_1dom_1_1events.html#a2628ea8d12e8b2563c32f05dc7fff6faa919fe92dbd9cd02f40a1e58f057d77bc',1,'com::sun::star::xml::dom::events']]],
  ['done_44',['DONE',['../namespacecom_1_1sun_1_1star_1_1util.html#a78015743cb8b25dbfc2b64889f6bd261a9c954bcf443428c80b0f107b3bc48749',1,'com::sun::star::util']]],
  ['dontknow_45',['DONTKNOW',['../namespacecom_1_1sun_1_1star_1_1awt.html#a0014b68cdf9686458deff56691368317adda60c0d628684cddc307a0bda81a260',1,'com::sun::star::awt']]],
  ['double_46',['DOUBLE',['../namespacecom_1_1sun_1_1star_1_1uno.html#a00683ed3ec24b47c36ead10a20d6f328a33465d1d419b1074fb259ef444609e92',1,'com::sun::star::uno::DOUBLE()'],['../namespacecom_1_1sun_1_1star_1_1drawing.html#a021284aa8478781ba1b958b81da7b608a33465d1d419b1074fb259ef444609e92',1,'com::sun::star::drawing::DOUBLE()']]],
  ['down_47',['DOWN',['../namespacecom_1_1sun_1_1star_1_1drawing.html#a218f9e180f159784cd3e33cef99bfe86a4ebb08896e48bdf5c496da779cbd955c',1,'com::sun::star::drawing::DOWN()'],['../namespacecom_1_1sun_1_1star_1_1sheet.html#a93cdb08109d5d34543f2fe04d1ef605aa9b0b4a95b99523966e0e34ffdadac9da',1,'com::sun::star::sheet::DOWN()']]],
  ['draft_48',['DRAFT',['../namespacecom_1_1sun_1_1star_1_1drawing.html#af49ab4b65513d2c0077f76b2227326e9a0b18dcbaa244a964cf244b6e3e894a28',1,'com::sun::star::drawing']]],
  ['draw_49',['DRAW',['../namespacecom_1_1sun_1_1star_1_1drawing.html#a15072729125e991609f3df469a03f611a61f3c57b6943c85413975507aede78cd',1,'com::sun::star::drawing']]],
  ['dsig_5finvalid_5freference_50',['DSIG_INVALID_REFERENCE',['../namespacecom_1_1sun_1_1star_1_1xml_1_1crypto.html#ab5d887eb5da1173b766d96d0d863d1dca770034bf39a46320ab5fc8df92ac3dee',1,'com::sun::star::xml::crypto']]],
  ['dsig_5fno_5freferences_51',['DSIG_NO_REFERENCES',['../namespacecom_1_1sun_1_1star_1_1xml_1_1crypto.html#ab5d887eb5da1173b766d96d0d863d1dca40b08485b5060322a1665ee640f6e7ab',1,'com::sun::star::xml::crypto']]],
  ['dynamic_52',['DYNAMIC',['../namespacecom_1_1sun_1_1star_1_1text.html#a1ed96de3f2d76e93588f67d506a0b0aeaaac65e0072e6ff1f4c3209d2fdd8730a',1,'com::sun::star::text']]]
];
